@@ -12,7 +12,7 @@ from octodns.provider.base import BaseProvider
 
 from .record import PowerDnsLuaRecord
 
-__VERSION__ = '0.0.2'
+__VERSION__ = '0.0.3'
 
 
 def _escape_unescaped_semicolons(value):
@@ -44,6 +44,7 @@ class PowerDnsBaseProvider(BaseProvider):
             'SPF',
             'SSHFP',
             'SRV',
+            'TLSA',
             'TXT',
             PowerDnsLuaRecord._type,
         )
@@ -121,6 +122,25 @@ class PowerDnsBaseProvider(BaseProvider):
     _data_for_AAAA = _data_for_multiple
     _data_for_NS = _data_for_multiple
 
+    def _data_for_TLSA(self, rrset):
+        values = []
+        for record in rrset['records']:
+            (
+                certificate_usage,
+                selector,
+                matching_type,
+                certificate_association_data,
+            ) = record['content'].split(' ', 3)
+            values.append(
+                {
+                    'certificate_usage': certificate_usage,
+                    'selector': selector,
+                    'matching_type': matching_type,
+                    'certificate_association_data': certificate_association_data,
+                }
+            )
+        return {'type': rrset['type'], 'values': values, 'ttl': rrset['ttl']}
+
     def _data_for_CAA(self, rrset):
         values = []
         for record in rrset['records']:
@@ -364,7 +384,11 @@ class PowerDnsBaseProvider(BaseProvider):
             exists = True
             for rrset in resp.json()['rrsets']:
                 _type = rrset['type']
-                if _type == 'SOA':
+                _provider_specific_type = f'PowerDnsProvider/{_type}'
+                if (
+                    _type not in self.SUPPORTS
+                    and _provider_specific_type not in self.SUPPORTS
+                ):
                     continue
                 data_for = getattr(self, f'_data_for_{_type}')
                 record_name = zone.hostname_from_fqdn(rrset['name'])
@@ -393,6 +417,15 @@ class PowerDnsBaseProvider(BaseProvider):
     _records_for_AAAA = _records_for_multiple
     _records_for_NS = _records_for_multiple
 
+    def _records_for_TLSA(self, record):
+        return [
+            {
+                'content': f'{v.certificate_usage} {v.selector} {v.matching_type} {v.certificate_association_data}',
+                'disabled': False,
+            }
+            for v in record.values
+        ], record._type
+
     def _records_for_CAA(self, record):
         return [
             {'content': f'{v.flags} {v.tag} "{v.value}"', 'disabled': False}
